package com.chinaitop.depot.basic.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import com.chinaitop.depot.basic.model.*;
import com.chinaitop.depot.basic.service.BasicStorehouseService;
import com.chinaitop.depot.basic.service.BasicUnitAisleService;
import com.chinaitop.depot.basic.service.BasicWarehouseService;
import com.chinaitop.depot.basic.model.BasicUnitAisle;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.common.service.ImportServiceImpl;
import com.chinaitop.mq.dto.jkEnum;
import com.chinaitop.mq.pub.RecPublishService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 廒间管理Controller
 *
 * @author User
 *
 */
@SuppressWarnings("all")
@RestController
@RequestMapping(value = "/UnitAisle")
@Api(value= "BasicStorehouseController", description = "廒间管理控制类")
public class BasicUnitAisleController {

    final static Logger logger = LoggerFactory.getLogger(BasicUnitAisle.class);

    @Resource
    private BasicUnitAisleService basicUnitAisleService;
    
    @Resource
	private BasicWarehouseService basicWarehouseService;
    
    @Value("${web.upload-path}")
    private String uploadPath;

    @Resource
    private ImportServiceImpl importService;
    
    @Resource
    private RecPublishService recPublishService;

    /**
     * 查找廒间信息
     *
     * @param pageNum 页数
     * @param pageSize 每页显示的条数
     * @param storeName 仓房名称
     * @param ajmc 廒间名称
     * @param orgId 单位ID
     * @param czbz 操作标志
     * @return
     */
    @RequestMapping(value = "/getUnitAisleList",produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询廒间信息数据列表", notes = "查询廒间信息数据列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "storeName", value = "仓房名称", paramType = "query"),
            @ApiImplicitParam(name = "ajmc", value = "廒间名称", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query"),
            @ApiImplicitParam(name = "czbz", value = "操作标志", paramType = "query")

    })
    public PageInfo<BasicUnitAisle> getUnitAisleList(Integer pageNum, Integer pageSize,
                                                     String storeName,
                                                     String ajmc, Integer orgId, String czbz) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<BasicUnitAisle> list = null;
        try {

            if (null != storeName && !"".equals(storeName)) {
                modelMap.put("storehouseName", storeName);
            }
            if (null != ajmc && !"".equals(ajmc)) {
                modelMap.put("ajmc", ajmc);
            }
            /* 只能查询当前单位的数据  */
            if (null != orgId) {
                modelMap.put("orgId", orgId);
            }
            if (null != czbz) {
                modelMap.put("czbz", czbz);
            }
            list = basicUnitAisleService.getList(modelMap);
        } catch (Exception e) {
            e.printStackTrace();
        }
        PageInfo<BasicUnitAisle> pageInfo = new PageInfo<BasicUnitAisle>(list);
        return pageInfo;
    }

    /**
     * 根据ID查找廒间信息
     *
     * @param id 数据ID
     * @return
     */
    @RequestMapping(value = "/findByUnitAisle",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据ID查找廒间信息", notes = "根据ID查找廒间信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "query")
    })
    public BasicUnitAisle findByUnitAisle(Integer id) {
        BasicUnitAisle basicUnitAisle = null;
        try {
            if (id != null) {
                basicUnitAisle = basicUnitAisleService.findByUnitAisle(id);
            } else {
                basicUnitAisle = new BasicUnitAisle();
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return basicUnitAisle;
    }

    @RequestMapping(value = "/edit",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.POST)
    @ApiOperation(value="更新廒间信息", notes = "更新廒间信息")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "storehouseJson", value = "JSON数据对象", paramType = "form"),
//            @ApiImplicitParam(name = "userInfo", value = "JSON登录对象", paramType = "form")
//    })
    public Map<String, Object> edit(@RequestParam("storehouseJson") String storehouseJson,@RequestParam("userInfo") String userInfo) {
        Map<String, Object> modelMap = null;
        try {
            System.out.println("-----------------------开始执行更新廒间操作--------------------------------");
            modelMap = basicUnitAisleService.saveOrUpdate(null, storehouseJson, userInfo);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        } finally {
            return modelMap;
        }
    }

    /**
     * 按仓房ID逻辑删除仓房信息
     *
     * @param id 数据ID
     * @return
     */
    @RequestMapping(value = "/remove", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="按廒间ID逻辑删除廒间信息", notes = "按廒间ID逻辑删除廒间信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public Map<String, Object> remove(Integer id) {
    	
		
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            // 先查询到这条数据
            BasicUnitAisle basicUnitAisle = basicUnitAisleService.findByUnitAisle(id);
            basicUnitAisle.setCzbz("d");
            basicUnitAisleService.updateBasicStorehouse(basicUnitAisle);
//            /* 更新单位表中仓房数、油罐数、有效仓容、有效罐容 */
//            basicStorehouseService.editOrgChNum(basicStorehouse.getOrgId());
            /* 同时删除这个仓房下的货位信息 */
            /*basicWarehouseService.deletEexample(basicStorehouse.getStorehouseId());*/
            
            //更改货位信息
            basicWarehouseService.updateDelFlagByAjId(basicUnitAisle.getId());
            
            
            /**
             * 国家局数据
             */
            String czbz = "d";
			recPublishService.sendMessage(czbz,jkEnum.aj.getTableName(),id+"",basicUnitAisle.getOrgId());

			
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "操作失败！");
        }
        return modelMap;
    }

    
    /**
	 * 根据单位和仓房查询廒间信息
	 * 
	 * @param unitId 单位ID
	 * @param storehouseId 仓房ID
	 * @return
	 */
	@RequestMapping(value="/getAisleInfo", method = RequestMethod.GET)
	@ApiOperation(value="根据单位和仓房查询廒间信息", notes = "根据单位和仓房查询廒间信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "unitId", value = "单位ID", paramType = "query"),
		@ApiImplicitParam(name = "storehouseId", value = "仓房ID", paramType = "query"),
		@ApiImplicitParam(name = "libraryType", value = "库类型(0主粮库,1代储库)", paramType = "query")
	})
	public Map<String, Object> getAisleInfo(Integer unitId, Integer storehouseId) {
		Map<String, Object> map = null;
		
		map = basicUnitAisleService.getAisleInfo(unitId, storehouseId);
		
		return map;
	}
	
	
	/**
     * 导入excel
     * @param file 文件
     * @param fileType 类型：如xlsx
     * @param request
     * @return
     */
    @RequestMapping(value="/importFile", method=RequestMethod.POST)
    @ApiOperation(value="导入廒间excel", notes = "导入廒间excel")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "file", value = "文件数据", paramType = "form"),
            @ApiImplicitParam(name = "fileType", value = "文件名称", paramType = "form"),
            @ApiImplicitParam(name = "userInfo", value = "JSON登录对象", paramType = "form"),
            @ApiImplicitParam(name = "orgId", value = "组织编码", paramType = "form")
    })
    public String importFile(MultipartFile file, String fileType,String userInfo, HttpServletRequest request,Integer orgId){
// 去掉开头的逗号
        if (userInfo.startsWith(",")) {
            userInfo = userInfo.substring(1);
        }

        JSONObject user = null;
        if (null != userInfo && !"".equals(userInfo)) {
            user = JSONObject.parseObject(userInfo);
        }

        String[] titleArr = {"*统一廒间编码","*廒间名称", "*仓房名称", "廒间长（米）","廒间宽（米）","廒间高（米）","*廒间设计仓容（吨）",
        		"*廒间启用日期", "廒间状态"};//第一行的title
        boolean[] emptyArr = {true,true,true,false,false,false,true,true,false};//指定列可为空，不可为空值为false.
        		

        List<List<String>> list = new ArrayList<List<String>>();//该list为数据返回的list
        String errormsg = null;
        try {
            errormsg = importService.importFile(uploadPath, file, fileType, request, titleArr, emptyArr, list);

            if (errormsg != null && !"".equals(errormsg)) {
                return errormsg;
            }

            if (list.size()>0) {
                errormsg = basicUnitAisleService.importData(list,user);
                System.out.println(list);
                System.out.println(errormsg);
                //errormsg = "导入成功！";
            }
        } catch (Exception e) {
            e.printStackTrace();
            errormsg = "导入失败！";
        }
        return errormsg;
    }

}
