package com.chinaitop.depot.basic.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.basic.mapper.BasicEnumMapper;
import com.chinaitop.depot.basic.mapper.BasicStorehouseMapper;
import com.chinaitop.depot.basic.mapper.BasicTankMapper;
import com.chinaitop.depot.basic.mapper.BasicWarehouseMapper;
import com.chinaitop.depot.basic.model.BasicEnum;
import com.chinaitop.depot.basic.model.BasicEnumExample;
import com.chinaitop.depot.basic.model.BasicStorehouse;
import com.chinaitop.depot.basic.model.BasicStorehouseExample;
import com.chinaitop.depot.basic.model.BasicTank;
import com.chinaitop.depot.basic.model.BasicTankExample;
import com.chinaitop.depot.basic.model.BasicStorehouseExample.Criteria;
import com.chinaitop.depot.basic.model.BasicWarehouse;
import com.chinaitop.depot.basic.model.BasicWarehouseExample;
import com.chinaitop.depot.basic.service.BasicEnumService;
import com.chinaitop.depot.basic.service.BasicKeeperHouseService;
import com.chinaitop.depot.basic.service.BasicKeeperService;
import com.chinaitop.depot.basic.service.BasicStorehouseService;
import com.chinaitop.depot.basic.service.BasicTankService;
import com.chinaitop.depot.basic.service.BasicWarehouseService;
import com.chinaitop.depot.system.mapper.OrgInfoMapper;
import com.chinaitop.depot.system.model.OrgInfo;
import com.chinaitop.depot.utils.BusinessUtils;
import com.chinaitop.mq.dto.jkEnum;
import com.chinaitop.mq.pub.PublishService;
import com.chinaitop.mq.pub.RecPublishService;
import com.chinaitop.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.chinaitop.depot.common.util.SecureMngr;
import com.chinaitop.depot.gjjsj.mapper.GjjMapper;

import org.springframework.transaction.annotation.Transactional;

@Service
@SuppressWarnings("all")
public class BasicStorehouseServiceImpl implements BasicStorehouseService {

	@Resource
	private BasicStorehouseMapper basic;

	@Resource
	private BasicWarehouseMapper wareMapper;
	
	@Resource
	private BasicWarehouseService warehouseService;

	@Resource
	private BasicEnumMapper enumMapper;

	@Resource
	private BasicEnumService basicEnumService;

	@Resource
	private BasicKeeperHouseService keeperHouseService;

	@Resource
	private BasicKeeperService keeperService;

	@Resource
	private BasicTankMapper basicTankMapper;

	@Resource
	private OrgInfoMapper orgInfoMapper;
	
	@Resource
    private RecPublishService recPublishService;
	
	@Resource
    private GjjMapper gjjMapper;
	
	
	

	@Override
	public void addBasicStorehouse(BasicStorehouse basicStorehouse) throws Exception {
		basic.insert(basicStorehouse);
	}

	@Override
	public void removeBasicStorehouse(Integer id) throws Exception {
		basic.deleteByPrimaryKey(id);
	}

	@Override
	public void updateBasicStorehouse(BasicStorehouse basicStorehouse) throws Exception {
		basic.updateByPrimaryKey(basicStorehouse);
	}

	@Override
	public BasicStorehouse findByPrimary(Integer id) throws Exception {
		return basic.selectByPrimaryKey(id);
	}

	@Override
	public BasicStorehouse findByPrimary1(Integer id) throws Exception {
		return basic.selectByPrimaryKey1(id);
	}

	@Override
	public List<BasicStorehouse> findBasicStorehouse(BasicStorehouseExample basicStorehouseExample) throws Exception {
		return basic.selectByExample(basicStorehouseExample);
	}

	@Override
	public List<BasicStorehouse> findBasicStorehouseNew(Map<String, Object> map) throws Exception {
		return basic.selectByExampleNew(map);
	}

	@Override
	public int count(BasicStorehouseExample basicStorehouseExample) throws Exception {
		return basic.countByExample(basicStorehouseExample);
	}

	@Override
	public Map<String, Object> getStorehouseData(Integer orgId, String libraryType) throws Exception {
		Map<String, Object> modelMap = new HashMap<String, Object>();

		/* 包含所有有效的仓房和油罐信息的下拉对象  */
		modelMap.put("house_and_tank_List", getStorehouseList(orgId, libraryType, null));

		/* 包含所有有效的仓房信息的下拉对象  */
		modelMap.put("houseList", getStorehouseList(orgId, libraryType, "0"));

		/* 包含所有有效的油罐信息的下拉对象  */
		modelMap.put("tankList", getStorehouseList(orgId, libraryType, "1"));

		/* 按ID来封装的包含所有仓房和油罐(有仓房的详细详细，油罐只有ID、code和name) */
		modelMap.put("houseObj", getStorehouseObj(orgId, libraryType, null));

		/* 按code来封装的包含所有仓房和油罐(有仓房的详细详细，油罐只有ID、code和name) */
		modelMap.put("houseCodeObj", getStorehouseCodeObj(orgId, libraryType, null));

		/* 包含所有油罐信息的下拉对象  */
		modelMap.put("tankObj", getTankObj(orgId, libraryType));

		return modelMap;
	}
	
	private Map<Integer, Object> getTankObj(Integer orgId, String libraryType) {
		BasicTankExample example = new BasicTankExample();
		BasicTankExample.Criteria criteria = example.createCriteria();
		List<BasicTank> tankObj = null;
		try {
			if (ParameterUtil.isnotnull(libraryType)) {
				criteria.andLibraryTypeEqualTo(libraryType);
			}else if(ParameterUtil.isnull(libraryType)){
				criteria.andLibraryTypeEqualTo("0");//如果不传值则默认查询主库数据，不查询代储库数据
			}
			if (ParameterUtil.isnotnull(orgId)) {
				criteria.andOrgIdEqualTo(orgId);
			}
			tankObj = basicTankMapper.selectByExample(example); //获取当前单位所有的仓房和油罐数据
		} catch (Exception e) {
			System.out.println(e.getMessage());
		}
		Map<Integer, Object> objMap = new HashMap<Integer, Object>();
		for (int i = 0; i < tankObj.size(); i++) {
			objMap.put(Integer.parseInt(tankObj.get(i).getId()), tankObj.get(i));
		}
		return objMap;
	}

	private List<BasicStorehouse> getStorehouseList(Integer orgId, String libraryType, String datatype) {
		List<BasicStorehouse> list = null;
		BasicStorehouseExample example = new BasicStorehouseExample();
		Criteria criteria = example.createCriteria();
		try {
			example.setOrderByClause("storehouse_id asc");
			if (ParameterUtil.isnotnull(orgId)) { 
				criteria.andOrgIdEqualTo(orgId);
			}
			if (ParameterUtil.isnotnull(libraryType)) {
				criteria.andLibraryTypeEqualTo(libraryType);
			}else if(ParameterUtil.isnull(libraryType)){
				criteria.andLibraryTypeEqualTo("0");//如果不传值则默认查询主库数据，不查询代储库数据
			}
			if (null != datatype && !"".equals(datatype)) {
				criteria.andDatatypeEqualTo(datatype);
			}
			criteria.andDelFlagEqualTo(1); // 查询正常数据
			list = basic.selectByExample(example); //获取当前单位下的所有有效仓房和油罐的下拉列表数据
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			return list;
		}
	}

	/**
	 * 获取当前单位下所有仓房和油罐数据(全局接口，不可随便修改)
	 *
	 * @param orgId
	 * @return
	 */
	private Map<Integer, Object> getStorehouseObj(Integer orgId,String libraryType, String datatype) {
		BasicStorehouseExample example = new BasicStorehouseExample();
		Criteria criteria = example.createCriteria();
		List<BasicStorehouse> houseObj = null;
		try {
			example.setOrderByClause("storehouse_id asc");

			if (ParameterUtil.isnotnull(libraryType)) {
				criteria.andLibraryTypeEqualTo(libraryType);
			}else if(ParameterUtil.isnull(libraryType)){
				criteria.andLibraryTypeEqualTo("0");//如果不传值则默认查询主库数据，不查询代储库数据
			}
			if (ParameterUtil.isnotnull(orgId)) {
				criteria.andOrgIdEqualTo(orgId);
			}
			if (null != datatype && !"".equals(datatype)) {
				criteria.andDatatypeEqualTo(datatype);
			}
			/*criteria.andDelFlagEqualTo(1); // 查询正常数据
*/			houseObj = basic.selectByExample(example); //获取当前单位所有的仓房和油罐数据
		} catch (Exception e) {
			e.printStackTrace();
		}
		Map<Integer, Object> objMap = new HashMap<Integer, Object>();
		for (BasicStorehouse obj : houseObj) {
			objMap.put(obj.getStorehouseId(), obj);
		}
		return objMap;
	}

	/**
	 * 获取当前单位下所有仓房数据-仓房编码(全局接口，不可随便修改)
	 *
	 * @param depotId
	 * @return
	 */
	private Map<String, Object> getStorehouseCodeObj(Integer orgId, String libraryType, String datatype) {
		BasicStorehouseExample example = new BasicStorehouseExample();
		Criteria criteria = example.createCriteria();
		List<BasicStorehouse> houseObj = null;
		try {
			example.setOrderByClause("storehouse_id asc");

			if (ParameterUtil.isnotnull(libraryType)) {
				criteria.andLibraryTypeEqualTo(libraryType);
			}else if(ParameterUtil.isnull(libraryType)){
				criteria.andLibraryTypeEqualTo("0");//如果不传值则默认查询主库数据，不查询代储库数据
			}
			if (ParameterUtil.isnotnull(orgId)) {
				criteria.andOrgIdEqualTo(orgId);
			}
			if (null != datatype && !"".equals(datatype)) {
				criteria.andDatatypeEqualTo(datatype);
			}
			//criteria.andDelFlagEqualTo(1); // 查询正常数据
			houseObj = basic.selectByExample(example); //获取当前单位所有的仓房数据
		} catch (Exception e) {
			e.printStackTrace();
		}
		Map<String, Object> objMap = new HashMap<>();
		for (BasicStorehouse obj : houseObj) {
			objMap.put(obj.getStorehouseCode(), obj);
		}
		return objMap;
	}

	@Override
	public String importData(List<List<String>> list, JSONObject user,String creditCode) {

		Integer orgId = null;
		String orgName = "";
		String username = "";
		if (null != user) {
			orgId = Integer.parseInt(user.get("orgId") == null?"":user.get("orgId").toString());
			orgName = user.get("orgName") == null?"":user.get("orgName").toString();
			username = user.get("username") == null?"":user.get("username").toString();
		}
		
		String  dwbm = creditCode;
				

		String uuid = null;
		Date date = new Date();
		Map<String, Integer> map = new HashMap<String, Integer>();
		BasicStorehouse storehouse = null;
		//BasicWarehouse warehouse = null;
		String msg = "";//消息
		boolean value_flag = false;
		int len = 0;//长度
		//根据字典名字查询字典编号
		BasicEnumExample enumExample = new BasicEnumExample();
		BasicEnumExample.Criteria Criteria = enumExample.createCriteria();
		List<BasicEnum> basicEnums;

		for (int i = 0; i < list.size(); i++) {
			List<String> revList = list.get(i);
			uuid = UUID.randomUUID().toString();

			for (int j = 0; j < revList.size(); j++) {
				switch(j) {
					case 0://仓房编号
						if (ParameterUtil.isnotnull(revList.get(j))) {
							len = revList.get(j).length();
							if (len != 3) {
								//msg = "第 "+(i+1)+" 行第 1 列的值的长度不能超过50！";
								msg = "第 "+(i+1)+" 行第 1 列的值的长度要等于3！";
								return msg;
							}

							Integer mapKey = map.get(revList.get(j));
							if (mapKey == null) {
								storehouse = new BasicStorehouse();
								map.put(revList.get(j), null);
								storehouse.setStorehouseCode(revList.get(j));
							}
						}
						break;
					case 1://统一仓房编码
						if (storehouse != null) {
							len = revList.get(j).length();
							if (len > 25) {
								msg = "第 "+(i+1)+" 行第 2 列的值的长度不能超过25！";
								return msg;
							}
							storehouse.setTycfbm(revList.get(j));
						}
						break;
					case 2://仓房名称
						if (storehouse != null) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 3 列的值的长度不能超过50！";
								return msg;
							}
							storehouse.setStorehouseName(revList.get(j));
						}
						break;
					case 3://仓房类型
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 4 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 11) {
								msg = "第 "+(i+1)+" 行第 4 列的值的长度不能超过11！";
								return msg;
							}
							storehouse.setStorehouseType(basicEnums.get(0).getEnumid());
						}
						break;
					/*case 3://设计仓容(吨)
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 4 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 4 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setDesignCapacity(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;*/
					case 4://交付使用日期
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							if(!ParameterUtil.stringIsTimeDate(revList.get(j))){
								msg = "第 "+(i+1)+" 行第 5 列的值不属于时间，请确认后再提交！";
								return msg;
							}
							storehouse.setUsedate(ParameterUtil.string2date(revList.get(j)));
						}
						break;
					case 5://建设单位
						if(revList.get(j) != null && revList.get(j).length()>0){
							storehouse.setJsdw(revList.get(j));
						}
						break;
					case 6://设计使用年限
						if(revList.get(j) != null && revList.get(j) != "" && revList.get(j).length()>0){
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 7 列的值只能是数字！";
								return msg;
							}
							storehouse.setSjsynx(revList.get(j));
						}
						break;
					case 7://设计单位
						if(revList.get(j) != null && revList.get(j).length()>0){
							storehouse.setJsdw(revList.get(j));
						}
						break;
					case 8://监理单位
						if(revList.get(j) != null && revList.get(j).length()>0){
							storehouse.setJsdw(revList.get(j));
						}
						break;
					case 9://墙体结构
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 10 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 11) {
								msg = "第 "+(i+1)+" 行第 10 列的值的长度不能超过11！";
								return msg;
							}
							storehouse.setWall(basicEnums.get(0).getEnumid());
						}
						break;
					case 10://房顶结构
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 11 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 11) {
								msg = "第 "+(i+1)+" 行第 11 列的值的长度不能超过11！";
								return msg;
							}
							storehouse.setRoof(basicEnums.get(0).getEnumid().toString());
						}
						break;
					case 11://房架结构
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 12 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 11) {
								msg = "第 "+(i+1)+" 行第 12 列的值的长度不能超过11！";
								return msg;
							}
							storehouse.setHouse(basicEnums.get(0).getEnumid().toString());
						}
						break;
					case 12://地面结构
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 13 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 11) {
								msg = "第 "+(i+1)+" 行第 13 列的值的长度不能超过11！";
								return msg;
							}
							storehouse.setGround(basicEnums.get(0).getEnumid().toString());
						}
						break;
					case 13://设计仓容(吨)
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 14 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 14 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setDesignCapacity(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 14://仓外长
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 15 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 15 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setStoreOutsideLength(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 15://仓外宽
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 16 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 16 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setStoreOutsideWidth(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 16://仓外檐高
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 17 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 17 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setStoreOutsideHeigth(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 17://仓外顶高
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 18 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 18 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setStoreOutsideTopHeigth(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 18://筒仓外径
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 19 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 19 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setOutsideSiloDiameter(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 19://仓内长
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 20 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 20 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setLength(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 20://仓内宽
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 21 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 21 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setWidth(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 21://仓内檐高
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 22 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 22 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setHeigth(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 22://仓内装粮线高
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 23 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 23 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setGrainLineHeigth(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 23://筒仓内径
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 24 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 24 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setSiloDiameter(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 24://仓内体积
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 25 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 25 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setBinVolume(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 25://仓门数量
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 26 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 26 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setHouseDoorNum(Integer.parseInt(revList.get(j)));
						}
						break;
					case 26://仓门位置
						if (revList.get(j)!= null && revList.get(j).length()>0) {
							storehouse.setHouseDootPosition(revList.get(j));
						}
						break;
					case 27://仓门高度
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 28 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 28 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setHouseDoorHeigth(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 28://仓门宽度
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 29 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 29 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setHouseDoorWidth(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 29://挡粮门型式
						if (revList.get(j) != null) {
							if(revList.get(j).equals("一字型挡粮板")){
								storehouse.setDlmxs("01");
							}else if(revList.get(j).equals("三角形挡粮门")){
								storehouse.setDlmxs("02");
							}else if(revList.get(j).equals("弧形挡粮门")){
								storehouse.setDlmxs("03");
							}else if(revList.get(j).equals("围包")){
								storehouse.setDlmxs("04");
							}else if(revList.get(j).equals("其它形式")){
								storehouse.setDlmxs("05");
							}else{
								msg = "第 "+(i+1)+" 行第 30 列的值不符合！";
								return msg;
							}
						}
						break;
					case 30://仓房是否完好
						if (revList.get(j) != null) {
							if(revList.get(j).equals("其他或不确定")){
								storehouse.setStorehouseState(3017);
							}else if(revList.get(j).equals("是")){
								storehouse.setStorehouseState(3011);
							}else if(revList.get(j).equals("否")){
								storehouse.setStorehouseState(3012);//待小修
							}else{
								msg = "第 "+(i+1)+" 行第 31 列的值不符合！";
								return msg;
							}
						}
						break;
					case 31://储粮功效
						if (revList.get(j) != null) {
							if(revList.get(j).equals("A类仓房")){
								storehouse.setClgx(0);
							}else if(revList.get(j).equals("B类仓房")){
								storehouse.setClgx(1);
							}else if(revList.get(j).equals("C类仓房")){
								storehouse.setClgx(2);
							}else if(revList.get(j).equals("D类仓房")){
								storehouse.setClgx(3);
							}else{
								msg = "第 "+(i+1)+" 行第 32 列的值不符合！";
								return msg;
							}
						}
						break;
					case 32://能否隔热保温
						if (revList.get(j) != null) {
							if(revList.get(j).equals("其他或不确定")){
								storehouse.setNfgrbw(9);
							}else if(revList.get(j).equals("能")){
								storehouse.setNfgrbw(1);
							}else if(revList.get(j).equals("否")){
								storehouse.setNfgrbw(0);
							}else{
								msg = "第 "+(i+1)+" 行第 33 列的值不符合！";
								return msg;
							}
						}
						break;
					case 33://隔热保温措施
						if (revList.get(j) != null && revList.get(j).length()>0) {
							storehouse.setGrbwcs(revList.get(j));
						}
						break;
					case 34://隔热性能
						if (revList.get(j) != null) {
							if(revList.get(j).equals("Ⅰ级")){
								storehouse.setGrxn(1);
							}else if(revList.get(j).equals("Ⅱ级")){
								storehouse.setGrxn(2);
							}else if(revList.get(j).equals("Ⅲ级")){
								storehouse.setGrxn(3);
							}else if(revList.get(j).equals("Ⅳ级")){
								storehouse.setGrxn(4);
							}else{
								msg = "第 "+(i+1)+" 行第 35 列的值不符合！";
								return msg;
							}
							
						}
						break;
					case 35://结构材料
						if (revList.get(j) != null) {
							if(revList.get(j).equals("Ⅰ级")){
								storehouse.setJgcl(1);
							}else if(revList.get(j).equals("Ⅱ级")){
								storehouse.setGrxn(2);
							}else if(revList.get(j).equals("Ⅲ级")){
								storehouse.setGrxn(3);
							}else{
								msg = "第 "+(i+1)+" 行第 36 列的值不符合！";
								return msg;
							}
							
						}
						break;
					case 36://气密性
						if (revList.get(j) != null) {
							if(revList.get(j).equals("Ⅰ级")){
								storehouse.setQmx(1);
							}else if(revList.get(j).equals("Ⅱ级")){
								storehouse.setGrxn(2);
							}else if(revList.get(j).equals("Ⅲ级")){
								storehouse.setGrxn(3);
							}else if(revList.get(j).equals("Ⅳ级")){
								storehouse.setGrxn(4);
							}else{
								msg = "第 "+(i+1)+" 行第 37 列的值不符合！";
								return msg;
							}
							
						}
						break;
					case 37://是否已进行信息化改造
						if (revList.get(j) != null) {
							if(revList.get(j).equals("是")){
								storehouse.setSfyjxxxhgz(1);
							}else if(revList.get(j).equals("否")){
								storehouse.setSfyjxxxhgz(0);
							}else{
								msg = "第 "+(i+1)+" 行第 38 列的值不符合！";
								return msg;
							}
						}
						break;
					case 38://粮情技术
						if (revList.get(j) != null) {
							if(revList.get(j).equals("Ⅰ级")){
								storehouse.setLqjs(1);
							}else if(revList.get(j).equals("Ⅱ级")){
								storehouse.setLqjs(2);
							}else if(revList.get(j).equals("Ⅲ级")){
								storehouse.setLqjs(3);
							}else if(revList.get(j).equals("无粮情检测技术")){
								storehouse.setLqjs(4);
							}else{
								msg = "第 "+(i+1)+" 行第 39 列的值不符合！";
								return msg;
							}
							
						}
						break;
					case 39://能否散装储存
						if (revList.get(j) != null) {
							if(revList.get(j).equals("其他或不确定")){
								storehouse.setNfszcc(9);
							}else if(revList.get(j).equals("能")){
								storehouse.setNfszcc(1);
							}else if(revList.get(j).equals("否")){
								storehouse.setNfszcc(0);
							}else{
								msg = "第 "+(i+1)+" 行第 40 列的值不符合！";
								return msg;
							}
						}
						break;
					case 40://有无防鼠防雀防虫装置及设施
						if (revList.get(j) != null) {
							if(revList.get(j).equals("其他或不确定")){
								storehouse.setYwfsfqfczz(9);
							}else if(revList.get(j).equals("有")){
								storehouse.setYwfsfqfczz(1);
							}else if(revList.get(j).equals("无")){
								storehouse.setYwfsfqfczz(0);
							}else{
								msg = "第 "+(i+1)+" 行第 41 列的值不符合！";
								return msg;
							}
						}
						break;
					case 41://有无防火防爆防盗设施
						if (revList.get(j) != null) {
							if(revList.get(j).equals("其他或不确定")){
								storehouse.setYwfhfbfdss(9);
							}else if(revList.get(j).equals("有")){
								storehouse.setYwfhfbfdss(1);
							}else if(revList.get(j).equals("无")){
								storehouse.setYwfhfbfdss(0);
							}else{
								msg = "第 "+(i+1)+" 行第 42 列的值不符合！";
								return msg;
							}
						}
						break;
					case 42://有无机械通风设施
						if (revList.get(j) != null) {
							if(revList.get(j).equals("其他或不确定")){
								storehouse.setYwjxtfss(9);
							}else if(revList.get(j).equals("有")){
								storehouse.setYwjxtfss(1);
							}else if(revList.get(j).equals("无")){
								storehouse.setYwjxtfss(0);
							}else{
								msg = "第 "+(i+1)+" 行第 43 列的值不符合！";
								return msg;
							}
						}
						break;
					case 43://通风系统型式
						if (revList.get(j) != null) {
							if(revList.get(j).equals("竖向通风")){
								storehouse.setTfxtxs(0);
							}else if(revList.get(j).equals("横向通风")){
								storehouse.setTfxtxs(1);
							}else if(revList.get(j).equals("径向通风")){
								storehouse.setTfxtxs(2);
							}else if(revList.get(j).equals("全网板通风")){
								storehouse.setTfxtxs(3);
							}else if(revList.get(j).equals("其他")){
								storehouse.setTfxtxs(4);
							}else{
								msg = "第 "+(i+1)+" 行第 44 列的值不符合！";
								return msg;
							}
						}
						break;
					case 44://通风技术
						if (revList.get(j) != null) {
							if(revList.get(j).equals("Ⅰ级")){
								storehouse.setTfjs(1);
							}else if(revList.get(j).equals("Ⅱ级")){
								storehouse.setTfjs(2);
							}else if(revList.get(j).equals("Ⅲ级")){
								storehouse.setTfjs(3);
							}else{
								msg = "第 "+(i+1)+" 行第 45 列的值不符合！";
								return msg;
							}
							
						}
						break;
					case 45://能否环流熏蒸杀虫
						if (revList.get(j) != null) {
							if(revList.get(j).equals("其他或不确定")){
								storehouse.setNfhlxzsc(9);
							}else if(revList.get(j).equals("能")){
								storehouse.setNfhlxzsc(1);
							}else if(revList.get(j).equals("否")){
								storehouse.setNfhlxzsc(0);
							}else{
								msg = "第 "+(i+1)+" 行第 46 列的值不符合！";
								return msg;
							}
						}
						break;
					case 46://杀虫技术
						if (revList.get(j) != null) {
							if(revList.get(j).equals("Ⅰ级")){
								storehouse.setScjs(1);
							}else if(revList.get(j).equals("Ⅱ级")){
								storehouse.setScjs(2);
							}else if(revList.get(j).equals("Ⅲ级")){
								storehouse.setScjs(3);
							}else{
								msg = "第 "+(i+1)+" 行第 47 列的值不符合！";
								return msg;
							}
							
						}
						break;
					case 47://能否富氮低氧气调储粮
						if (revList.get(j) != null) {
							if(revList.get(j).equals("其他或不确定")){
								storehouse.setNffddyqtcl(9);
							}else if(revList.get(j).equals("能")){
								storehouse.setNffddyqtcl(1);
							}else if(revList.get(j).equals("否")){
								storehouse.setNffddyqtcl(0);
							}else{
								msg = "第 "+(i+1)+" 行第 48 列的值不符合！";
								return msg;
							}
						}
						break;
					case 48://控温技术
						if (revList.get(j) != null) {
							if(revList.get(j).equals("Ⅰ级")){
								storehouse.setKwjs(1);
							}else if(revList.get(j).equals("Ⅱ级")){
								storehouse.setKwjs(2);
							}else if(revList.get(j).equals("Ⅲ级")){
								storehouse.setKwjs(3);
							}else{
								msg = "第 "+(i+1)+" 行第 49 列的值不符合！";
								return msg;
							}
							
						}
						break;
					case 49://害虫检测方式
						if (revList.get(j) != null) {
							if(revList.get(j).equals("远程监测预警")){
								storehouse.setHcjcfs("01");
							}else if(revList.get(j).equals("人工手动筛查")){
								storehouse.setHcjcfs("02");
							}else if(revList.get(j).equals("其他方式")){
								storehouse.setHcjcfs("03");
							}else{
								msg = "第 "+(i+1)+" 行第 50 列的值不符合！";
								return msg;
							}
							
						}
						break;
					case 50://仓房状态
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 51 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 11) {
								msg = "第 "+(i+1)+" 行第 51 列的值的长度不能超过11！";
								return msg;
							}
							storehouse.setStorehouseState(basicEnums.get(0).getEnumid());
						}
						break;
					case 51://仓房经度
						if (revList.get(j)!= null && revList.get(j).length()>0) {
							storehouse.setCfjd(new BigDecimal(revList.get(j)));
						}
						break;
					case 52://仓房weidu
						if (revList.get(j)!= null && revList.get(j).length()>0) {
							storehouse.setCfwd(new BigDecimal(revList.get(j)));
						}
						
						String cfbm = "";//仓房编码
						String ajbm = "";//廒间编码

						if (!"".equals(storehouse.getStorehouseCode())) {
							cfbm = BusinessUtils.setBZcfandygbm(dwbm, storehouse.getStorehouseCode(), "0", orgId+"");
							ajbm = BusinessUtils.setBZajbm(cfbm, storehouse.getStorehouseType()+"", "0");
							storehouse.setCfbm(cfbm.trim());
						}
						
						//插入仓房信息
						if (storehouse != null) {
							
							    storehouse.setCreatename(username);
								storehouse.setDepotId(orgId);
								storehouse.setDepotName(orgName);
								storehouse.setLibraryType("0");
								storehouse.setUuid(uuid);
								storehouse.setDelFlag(1);
								storehouse.setCreatedate(date);
								storehouse.setOrgId(orgId);
								storehouse.setDatatype("0");//仓房
							
							//校验仓房编码不可重复
							boolean flag = uniqueParityCheck("house", storehouse.getStorehouseCode(), orgId, null);
							if (!flag) {
								msg = "第 "+(i+1)+" 行的仓房编号已在数据库存在！";
								return msg;
							}
							basic.insert(storehouse);
							map.put(storehouse.getStorehouseCode(), storehouse.getStorehouseId());
						}
						
					/*case 5://实际仓容(吨)
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 5 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 5 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setActualCapacity(BigDecimal.valueOf(Integer.parseInt(revList.get(j))));
						}
						break;
					case 5://通风方式
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 6 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 100) {
								msg = "第 "+(i+1)+" 行第 6 列的值的长度不能超过100！";
								return msg;
							}
							storehouse.setDrafttype(basicEnums.get(0).getEnumid());
						}
						break;
					case 6://保管方式
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 7 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 100) {
								msg = "第 "+(i+1)+" 行第 7 列的值的长度不能超过100！";
								return msg;
							}
							storehouse.setKeepingWay(basicEnums.get(0).getEnumid());
						}
						break;
					case 7://装粮线高度(m)
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							value_flag = revList.get(j).matches("[0-9]+");
							if (!value_flag) {
								msg = "第 "+(i+1)+" 行的第 8 列的值只能是数字！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 30) {
								msg = "第 "+(i+1)+" 行第 8 列的值的长度不能超过30！";
								return msg;
							}
							storehouse.setGrainHeigth(new BigDecimal(revList.get(j)));
						}
						break;*/
					/*case 8://保管员 注：liangs 2019/07/08 注掉保管员列
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 9 列的值的长度不能超过50！";
								return msg;
							}
							storehouse.setDutystoreman(revList.get(j));
						}
						break;*/
					/*case 8://仓房状态
						if (ParameterUtil.isnotnull(revList.get(j)) && storehouse != null) {
							enumExample.clear();
							Criteria = enumExample.createCriteria();
							Criteria.andEnumnameEqualTo(revList.get(j));
							basicEnums = enumMapper.selectByExample(enumExample);
							if(basicEnums.size() == 0){
								msg = "第 "+(i+1)+" 行第 9 列的值不正确，请查找后在导入！";
								return msg;
							}
							len = revList.get(j).length();
							if (len > 11) {
								msg = "第 "+(i+1)+" 行第 9 列的值的长度不能超过11！";
								return msg;
							}
							storehouse.setStorehouseState(basicEnums.get(0).getEnumid());
						}
						break;
					
					case 10://货位编号
						if (ParameterUtil.isnotnull(revList.get(j))) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 11 列的值的长度不能超过50！";
								return msg;
							}

							warehouse = new BasicWarehouse();
							warehouse.setWarehouseCode(revList.get(j));
						}
						break;
					case 11://货位名称
						if (ParameterUtil.isnotnull(revList.get(j))) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 12 列的值的长度不能超过50！";
								return msg;
							}
							if (warehouse != null) {
								warehouse.setWarehouseName(revList.get(j));
							}
						}
						break;
					case 12://货位容量(吨)
						if (ParameterUtil.isnotnull(revList.get(j))) {
							len = revList.get(j).length();
							if (len > 50) {
								msg = "第 "+(i+1)+" 行第 13 列的值的长度不能超过50！";
								return msg;
							}
							if (warehouse != null) {
								warehouse.setWarehouseCapacity(new BigDecimal(revList.get(j)));
							}
						}
						if (warehouse != null) {
							warehouse.setDelFlag(1);
							warehouse.setCreatedate(date);
							warehouse.setOrgId(orgId);
							warehouse.setWarehouseStatus(2963); //添加时默认货位状态为空仓
						}
						break;
					case 13:
						if (ParameterUtil.isnotnull(revList.get(j))) {
							//插入仓房信息
							if (storehouse != null) {
								storehouse.setLibraryType(revList.get(j));
							}
							if (warehouse != null) {
								warehouse.setLibraryType(revList.get(j));
							}
						}
						break;*/
					/*case 14:
						//if (ParameterUtil.isnotnull(revList.get(j))) {
							Map<String,Object> depotMap = new HashMap<String, Object>();
							if ("1".equals(storehouse.getLibraryType())) {
								depotMap.put("agentDepotName",revList.get(j));
								depotMap = basic.getAgentDepotId(depotMap);
								if(ParameterUtil.isnull(depotMap)){
									msg = "第 "+(i+1)+" 行第 15 列的值的不正确，请查询后再添加！";
									return msg;
								}
							}*/
							//插入仓房信息
							/*if (storehouse != null) {
								if(ParameterUtil.isequal("1",storehouse.getLibraryType())){
									storehouse.setDepotId(Integer.parseInt(depotMap.get("id").toString()));
									storehouse.setDepotName(revList.get(j));
								}else{
									storehouse.setDepotId(orgId);
									storehouse.setDepotName(orgName);
								}
								//校验仓房编码不可重复
								boolean flag = uniqueParityCheck("house", storehouse.getStorehouseCode(), orgId, null);
								if (!flag) {
									msg = "第 "+(i+1)+" 行的仓房编码已在数据库存在！";
									return msg;
								}
								basic.insert(storehouse);
								map.put(storehouse.getStorehouseCode(), storehouse.getStorehouseId());
							}*/
							/*if (warehouse != null) {
								if(ParameterUtil.isequal("1",warehouse.getLibraryType())){
									warehouse.setDepotId(Integer.parseInt(depotMap.get("id").toString()));
									warehouse.setDepotName(revList.get(j));
								}else{
									warehouse.setDepotId(orgId);
									warehouse.setDepotName(orgName);
								}
								//校验货位编码不可重复
								boolean flag = uniqueParityCheck("ware", revList.get(j), orgId, map.get(revList.get(0)));
								if (!flag) {
									msg = "第 "+(i+1)+" 行的仓房编码已在数据库存在！";
									return msg;
								}
								warehouse.setStorehouseId(map.get(revList.get(0)));
								wareMapper.insert(warehouse);
							}*/
						//}
						storehouse = null;
						//warehouse = null;
						break;
					default :
						break;

				}

			}

		}
		return msg;
	}

	/**
	 * 校验仓房或货位的编码是否存在
	 * 
	 * @param type 标识符
	 * @param code 编码值
	 * @param orgId 单位ID
	 * @param houseId 仓房ID
	 * @return
	 */
	private boolean uniqueParityCheck(String type, String code, Integer orgId, Integer houseId) {
		boolean flag = false;
		
		if ("house".equals(type)) {
			BasicStorehouseExample example = new BasicStorehouseExample();
			Criteria criteria = example.createCriteria();
			criteria.andOrgIdEqualTo(orgId);
			criteria.andStorehouseCodeEqualTo(code);
			criteria.andLibraryTypeEqualTo("1");
			List<BasicStorehouse> list = basic.selectByExample(example);
			if (null == list || list.size() == 0) {
				flag = true;
			}
		}
		if ("ware".equals(type)) {
			BasicWarehouseExample example = new BasicWarehouseExample();
			BasicWarehouseExample.Criteria criteria = example.createCriteria();
			criteria.andOrgIdEqualTo(orgId);
			criteria.andWarehouseCodeEqualTo(code);
			criteria.andStorehouseIdEqualTo(houseId);
			criteria.andLibraryTypeEqualTo("1");
			List<BasicWarehouse> list = wareMapper.selectByExample(example);
			if (null == list || list.size() == 0) {
				flag = true;
			}
		}
		
		return flag;
	}

	@Override
	public String getStorehouseKeeper(Integer id, Integer orgId, boolean flag) {
		String keeperNames = "";

		/* 获取这个仓房的所有保管员的员工ID */
		List<Integer> keep_list = keeperHouseService.getKeeperId(orgId, id);

		//2、然后把这些人的翻译过来，展示出来
		if (null != keep_list && keep_list.size() > 0) {
			keeperNames = keeperService.getKeeperNames(keep_list);
			if (flag) {
				if (keeperNames.length() > 7) {
					keeperNames = keeperNames.substring(0, 7) + "...";
				}
			}
		}

		return keeperNames;
	}
	

	@Override
	public Map<String, Object> getThreeTempCheckList(Integer orgId) {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		Map<String, Object> map = new HashMap<String, Object>();
		List<BasicStorehouse> houselist = null;
		try {
			if (ParameterUtil.isnotnull(orgId)) {
				map.put("orgId", orgId);
			}
			map.put("libraryType", 0);//默认查询主库数据，不查询代储库数据
			map.put("delFlag", 1);//查询正常数据
			houselist = basic.getThreeTempCheckList(map); //获取当前单位下的所有有效数据
		} catch (Exception e) {
			e.printStackTrace();
		}
		modelMap.put("houseList", houselist);
		return modelMap;
	}

	@Override
	public BasicStorehouse getStoreDataByHouseId(int houseId) {
		// TODO Auto-generated method stub
		return basic.getStoreDataByHouseId(houseId);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public Map<String, Object> saveOrUpdate(HttpServletRequest request, String storehouseJson, String warehouseJson, String userInfo,String kqdm) throws Exception {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		JSONObject user = null;
		JSONObject org = null;
		Integer orgId = null;
		String userName = "";
		if (null != userInfo && !"".equals(userInfo)) {
			user = JSONObject.parseObject(userInfo);
			orgId = Integer.parseInt(user.get("orgId") == null?"":user.get("orgId").toString());
			userName = user.get("username") == null?"":user.get("username").toString();
		}

		Date date = new Date();

		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		BasicStorehouse basicStorehouse = (BasicStorehouse) mapper.readValue(storehouseJson, BasicStorehouse.class);
		basicStorehouse.setDelFlag(1);
		
		String cfbm = "";//仓房编码

		if (!"".equals(basicStorehouse.getStorehouseCode())) {
			cfbm = BusinessUtils.setBZcfdmandygbm(kqdm, basicStorehouse.getStorehouseCode(), "0");
			basicStorehouse.setCfbm(cfbm.trim());
		}
		
		String czbz;
		
		if (basicStorehouse.getStorehouseId() == null) {
			//String uuid = UUID.randomUUID().toString();
			String uuid = UUID.randomUUID().toString().replaceAll("-", "");
			basicStorehouse.setUuid(uuid);

			if(!ParameterUtil.isequal(basicStorehouse.getLibraryType(),"1")){
				basicStorehouse.setDepotId(orgId);
			}
			basicStorehouse.setOrgId(orgId);
			basicStorehouse.setCreatename(userName);
			basicStorehouse.setCreatedate(date);
			basicStorehouse.setDatatype("0");

			basic.insert(basicStorehouse);
			
			czbz = "i";
			
		} else {
			basicStorehouse.setDatatype("0");
			basicStorehouse.setDutystoreman(null);
			basicStorehouse.setUpdatename(userName);
			basicStorehouse.setUpdatedate(date);

			basic.updateByPrimaryKey(basicStorehouse);
			
			/**
			 * 获取上传国家局的数据 
			 */
			czbz = "u";
			
		}

		//更新货位数据
		//warehouseService.saveOrUpdate(basicStorehouse, warehouseJson);

		//更新单位表仓房数、油罐数、有效仓容、有效罐容
		editOrgChNum(orgId);
		modelMap.put("status", "success");
		
		
		/**
		 * 国家局
		 */
		
		//操作标志 、表名、业务id、单位id
		recPublishService.sendMessage(czbz,jkEnum.cf.getTableName(),basicStorehouse.getStorehouseId()+"",basicStorehouse.getOrgId());
			

		return modelMap;
	}
	
	@Override
	public void editOrgChNum(Integer orgId) throws Exception {
		//查询当前单位仓房数
		BasicStorehouseExample cf_example = new BasicStorehouseExample();
		BasicStorehouseExample.Criteria cf_criteria = cf_example.createCriteria();
		cf_criteria.andOrgIdEqualTo(orgId);
		cf_criteria.andLibraryTypeEqualTo("0");
		cf_criteria.andDelFlagEqualTo(1);
		cf_criteria.andDatatypeEqualTo("0");
		int ch_count = basic.countByExample(cf_example);
		
		//查询当前单位的油罐数
		BasicTankExample yg_example = new BasicTankExample();
		BasicTankExample.Criteria yg_criteria = yg_example.createCriteria();
		yg_criteria.andOrgIdEqualTo(orgId);
		yg_criteria.andLibraryTypeEqualTo("0");
		yg_criteria.andDelFlagEqualTo(1);
		int yg_count = basicTankMapper.countByExample(yg_example);

		//查询当前单位仓房总实际容量和油罐总实际容量
		Map<String, Object> rl_map = basic.queryCrAndgw(orgId);

		//更新当前单位下仓房数、油罐数数、有效仓房、有效罐容
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("orgId", orgId);
		map.put("cf_count", ch_count);
		map.put("yg_count", yg_count);
		map.put("cr_count", rl_map.get("cr_count"));
		map.put("gr_count", rl_map.get("gr_count"));

		basic.editOrgCfAndHwNum(map);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public Map<String, String> saveOrUpdateSptStorehouseData(String datas) throws Exception {
		Map<String, String> resultMap = new HashMap<>();
		BasicStorehouse storehouse = null;
		List<BasicWarehouse> warehouse_list = null;
		Map<String, String> isadd_map = null;

		JSONObject obj = null;
		JSONArray hwarray = null;
		JSONArray cmarray = null;

        if (StringUtils.isNotBlank(datas)) {
        	obj = JSONObject.parseObject(datas);
        	
        	//货位数据
        	String hwstring = obj.getString("hwxxsjyVOList");
    		if (StringUtils.isNotBlank(hwstring)) {
    			hwarray = JSON.parseArray(hwstring);
    			if (hwarray.size() == 0) {
    				resultMap.put("status", "error");
    	        	resultMap.put("msg", "至少要有一条货位数据!");
    	        	return resultMap;
    			}
    		} else {
    			resultMap.put("status", "error");
	        	resultMap.put("msg", "至少要有一条货位数据!");
	        	return resultMap;
    		}
    		
    		//仓门数据
        	String cmstring = obj.getString("warehouseDoorVOList");
    		if (StringUtils.isNotBlank(cmstring)) {
    			cmarray = JSON.parseArray(cmstring);
    			if (cmarray.size() == 0) {
    				resultMap.put("status", "error");
    	        	resultMap.put("msg", "至少要有一条仓门数据!");
    	        	return resultMap;
    			}
    		} else {
    			resultMap.put("status", "error");
	        	resultMap.put("msg", "至少要有一条仓门数据!");
	        	return resultMap;
    		}
        } else {
        	resultMap.put("status", "error");
        	resultMap.put("msg", "所传的数据串是空的!");
        	return resultMap;
        }
        
        Map<String, Object> check = dataCheck(obj, hwarray, cmarray);
        String msg = check.get("msg").toString();
        if (msg.length() == 0) {
        	storehouse = (BasicStorehouse)check.get("storehouse");
        	warehouse_list = (List<BasicWarehouse>) check.get("ware_list");
        	isadd_map = (Map<String, String>) check.get("isadd_map");

        	//持久化仓房表的数据
        	if (null == storehouse.getStorehouseId()) {
        		basic.insert(storehouse);
        	} else {
        		basic.updateByPrimaryKey(storehouse);
        	}

        	//持久化货位数据
        	for (int i = 0; i < warehouse_list.size(); i++) {
        		if ("true".equals(isadd_map.get(warehouse_list.get(i).getSptDataid()))) {
        			warehouse_list.get(i).setStorehouseId(storehouse.getStorehouseId());
        			wareMapper.insertSelective(warehouse_list.get(i));
        		} else {
        			wareMapper.updateByPrimaryKeySelective(warehouse_list.get(i));
        		}
        	}

			resultMap.put("status", "success");
        	resultMap.put("msg", "操作成功");
		} else {
			resultMap.put("status", "error");
        	resultMap.put("msg", msg);
		}
        
		return resultMap;
	}

	/**
	 * 校验市平台传过来的油罐数据
	 * @param obj 原数据object
	 * @param hwarray 货位数据
	 * @param cmarray 仓门数据
	 * @return
	 * @throws Exception
	 */
	public Map<String, Object> dataCheck(JSONObject obj, JSONArray hwarray, JSONArray cmarray) throws Exception {

		Map<String, Object> map = new HashMap<>();
		StringBuffer sbf = new StringBuffer(100);

		BasicStorehouse storehouse = new BasicStorehouse();
		List<BasicWarehouse> ware_list = new ArrayList<>();

		Integer orgId = null;
		String orgName = null;
		BigDecimal zj = null;

		//库区标准编码
    	String kqdm = obj.getString("kqdm");
    	if (StringUtils.isNotBlank(kqdm)) {
    		OrgInfo orgInfo = orgInfoMapper.selectByPrimaryKey(kqdm.trim());
        	if (null != orgInfo && !"".equals(orgInfo)) {
        		orgId = orgInfo.getOrgId();
        		orgName = orgInfo.getOrgName();
        		storehouse.setDepotId(orgInfo.getOrgId());
        		storehouse.setOrgId(orgInfo.getOrgId());
        		storehouse.setOrgName(orgName);
        		storehouse.setDepotName(orgInfo.getOrgName());
        		storehouse.setDatatype("0");
        	} else {
        		sbf.append("kqdm有误;");
        		String msg = sbf.toString();
        		map.put("msg", msg);
        		return map;
        	}
		} else {
			sbf.append("kqdm不能为空;");
    		String msg = sbf.toString();
    		map.put("msg", msg);
    		return map;
		}
    	
    	/********遍历货位数据 start*********/

    	StringBuffer wsb = null;
    	JSONObject ware_obj = null;//货位字符串对象
    	Map<String, String> isadd_map = new HashMap<>();//标记每条货位是否是新增
    	BasicWarehouse warehouse = null;//货位实体对象数据

    	for (int j = 0; j < hwarray.size(); j++) {

    		wsb = new StringBuffer(100);
    		ware_obj = hwarray.getJSONObject(j);
 
    		warehouse = new BasicWarehouse();

    		//市平台货位唯一主键ID
    		String cfbh = ware_obj.getString("cfbh");
    		if (StringUtils.isNotBlank(cfbh)) {
    			BasicWarehouseExample example = new BasicWarehouseExample();
    			BasicWarehouseExample.Criteria criteria = example.createCriteria();
    			criteria.andSptDataidEqualTo(cfbh.trim());
    			List<BasicWarehouse> warecheck_list = wareMapper.selectByExample(example);
        		if (null != warecheck_list && warecheck_list.size() > 0) {//修改
        			isadd_map.put(cfbh.trim(), "false");//数据库里有这个id对应的数据，那就说明是修改
        			warehouse = warecheck_list.get(0);
        			if (storehouse.getStorehouseId() == null) {
        				storehouse.setStorehouseId(warehouse.getStorehouseId());
        			}
        		} else {//新增
        			isadd_map.put(cfbh.trim(), "true");
        			warehouse.setOrgId(orgId);
        			warehouse.setDepotId(orgId);
        			warehouse.setDepotName(orgName);
        			warehouse.setDelFlag(1);
        			warehouse.setCreatedate(new Date());
        			warehouse.setLibraryType("0");
        			warehouse.setCrkStatus("1");
        		}
        		warehouse.setSptDataid(cfbh.trim());
        	} else {
        		wsb.append("cfbh不能为空;");
        		break;
        	}

    		//货位代码
    		String hwdm = ware_obj.getString("hwdm");
    		if (StringUtils.isNotBlank(hwdm) && hwdm.trim().length() == 30) {
    			warehouse.setHwdm(hwdm);
    		} else {
    			wsb.append("hwdm不能为空且长度必须是30位;");
    		}

    		//货位名称
    		String hwmc = ware_obj.getString("cfmc");
    		if (StringUtils.isNotBlank(hwmc)) {
    			warehouse.setWarehouseName(hwmc.trim());
    		} else {
    			wsb.append("hwmc不能为空且长度必须是30位;");
    		}

    		//货位编号
    		String hwxh = ware_obj.getString("hwxh");
    		if (StringUtils.isNotBlank(hwxh) && hwxh.trim().length() == 2) {
    			//先判断是否编码重复,要在市平台油罐基础数据主键ID不为空的情况下判断
    			if (StringUtils.isNotBlank(warehouse.getSptDataid()) && warehouse.getOrgId() != null && storehouse.getStorehouseId() != null) {
    				BasicWarehouseExample example = new BasicWarehouseExample();
    				BasicWarehouseExample.Criteria criteria = example.createCriteria();
    				criteria.andOrgIdEqualTo(warehouse.getOrgId());
    				criteria.andStorehouseIdEqualTo(storehouse.getStorehouseId());
    				criteria.andWarehouseCodeEqualTo(hwxh);
    				if ("false".equals(isadd_map.get(warehouse.getSptDataid()))) {//如果是修改，那么判断时要排除掉要修改的这条数据
    					criteria.andSptDataidNotEqualTo(warehouse.getSptDataid());
    				}
    				List<BasicWarehouse> list = wareMapper.selectByExample(example);
    				if (null != list && list.size() > 0) {
    					wsb.append("hwxh货位编码重复了;");
    				}
    			}
    			warehouse.setWarehouseCode(hwxh.trim());
    		} else {
    			wsb.append("hwxh不能为空且长度必须是2位;");
    		}

    		//货位启用日期
    		String qyrq = ware_obj.getString("qyrq");
    		if (StringUtils.isNotBlank(qyrq)) {
    			warehouse.setWarehouseUseTime(ParameterUtil.string2date(qyrq.trim()));
    		} else {
    			wsb.append("qyrq不能为空且长度必须是30位;");
    		}

    		//货位容量
    		String hwrl = ware_obj.getString("hwrl");
    		if (StringUtils.isNotBlank(hwrl)) {
    			warehouse.setWarehouseCapacity(ParameterUtil.getBigDecimal(hwrl.trim(), 3));
    		}

    		//货位120编码
    		String cfbm = ware_obj.getString("cfbm");
    		if (StringUtils.isNotBlank(cfbm)) {
    			warehouse.setHwbm(cfbm.trim());
    		}
    		
    		String delflag = ware_obj.getString("status");
        	if (StringUtils.isNotBlank(delflag)) {
        		warehouse.setDelFlag(Integer.parseInt(delflag.trim()));
        	} else {
        		wsb.append("status货位的弃用状态不能为空;");
        	}
    		
    		if (wsb.toString().length() > 0) {
    			sbf.append("第").append(j+1).append("条货位数据中的").append(wsb);
    		}
    		
    		ware_list.add(warehouse);
    		   
    	}
    	/********遍历货位数据 end*********/

    	//仓房编号(三位的那个编号)
    	String cfxh = obj.getString("cfxh");
    	if (StringUtils.isNotBlank(cfxh)) {
    		//判断仓房数据是否需要新增,并且判断仓房编号是否重复
    		BasicStorehouseExample store_example = new BasicStorehouseExample();
    		BasicStorehouseExample.Criteria criteria = store_example.createCriteria();
    		criteria.andOrgIdEqualTo(orgId);
    		criteria.andStorehouseCodeEqualTo(cfxh.trim());
    		criteria.andDatatypeEqualTo("0");
    		if (null != storehouse.getStorehouseId()) {//说明当前仓房属于修改
    			
    			//先把当前仓房数据查询出来，后面在用数据串中的数据一个个的覆盖
    			storehouse = basic.selectByPrimaryKey(storehouse.getStorehouseId());
    			
    			//修改的情况下，校验过程不能包含当前这条数据
    			criteria.andStorehouseIdNotEqualTo(storehouse.getStorehouseId());
    		} else {
    			storehouse.setDelFlag(1);
    			storehouse.setLibraryType("0");
    			storehouse.setCreatedate(new Date());
    			storehouse.setUpdatedate(storehouse.getCreatedate());
    		}
    		List<BasicStorehouse> list = basic.selectByExample(store_example);
    		if (null != list && list.size() > 0) {
    			sbf.append("当前仓的仓房编号重复;");
    		}

    		storehouse.setStorehouseCode(cfxh.trim());
    	} else {
    		sbf.append("cfxh不能为空;");
    	}

    	//仓房标准编码
    	String cfbzbm = obj.getString("gfcfdm");
    	if (StringUtils.isNotBlank(cfbzbm) && cfbzbm.length() == 25) {
    		storehouse.setCfbm(cfbzbm.trim());
    	} else {
    		sbf.append("gfcfdm不能为空并且必须是25位;");
    	}

    	//仓房名称
    	String gfcfmc = obj.getString("gfcfmc");
    	if (StringUtils.isNotBlank(gfcfmc)) {
    		storehouse.setStorehouseName(gfcfmc.trim());
    	} else {
    		sbf.append("gfcfmc不能为空;");
    	}

    	//仓房类型
    	String cflxbh = obj.getString("cflx");
    	if (StringUtils.isNotBlank(cflxbh)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(1064, cflxbh.trim());
    		if (null != emm) {
    			storehouse.setStorehouseType(emm.getEnumid());
    		} else {
    			sbf.append("cflxbh参数有误;");
    		}
    	} else {
    		sbf.append("cflxbh不能为空;");
    	}

    	//交付使用日期
    	String jfsyrq = obj.getString("jfsyrq");
    	if (StringUtils.isNotBlank(jfsyrq)) {
    		storehouse.setUsedate(ParameterUtil.string2date(jfsyrq));
    	}

    	//建设单位
    	String jsdw = obj.getString("jsdw");
    	if (StringUtils.isNotBlank(jsdw)) {
    		storehouse.setJsdw(jsdw.trim());
    	}

    	//设计使用年限
    	String sjnx = obj.getString("sjsynx");
    	if (StringUtils.isNotBlank(sjnx)) {
    		storehouse.setSjsynx(sjnx.trim());
    	}

    	//设计单位
    	String sjdw = obj.getString("sjdw");
    	if (StringUtils.isNotBlank(sjdw)) {
    		storehouse.setSjdw(sjdw.trim());
    	}

    	//监理单位
    	String jldw = obj.getString("jldw");
    	if (StringUtils.isNotBlank(jldw)) {
    		storehouse.setJldw(jldw.trim());
    	}

    	//仓房墙体结构
    	String qtjg = obj.getString("qtjg");
    	if (StringUtils.isNotBlank(qtjg)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(7528, qtjg.trim());
    		if (null != emm) {
    			storehouse.setWall(emm.getEnumid());
    		} else {
    			sbf.append("qtjg参数有误;");
    		}
    	} else {
    		sbf.append("qtjg不能为空;");
    	}

    	//仓房房顶结构
    	String fdjg = obj.getString("fdjg");
    	if (StringUtils.isNotBlank(fdjg)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(7529, fdjg.trim());
    		if (null != emm) {
    			storehouse.setRoof(emm.getEnumid().toString());
    		} else {
    			sbf.append("fdjg参数有误;");
    		}
    	} else {
    		sbf.append("fdjg不能为空;");
    	}
    	
    	//仓房房架结构
    	String fjjg = obj.getString("fjjg");
    	if (StringUtils.isNotBlank(fjjg)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(7530, fjjg.trim());
    		if (null != emm) {
    			storehouse.setHouse(emm.getEnumid().toString());
    		} else {
    			sbf.append("fjjg参数有误;");
    		}
    	} else {
    		sbf.append("fjjg不能为空;");
    	}

    	//仓房地面结构
    	String dmjg = obj.getString("dmjg");
    	if (StringUtils.isNotBlank(dmjg)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(7531, dmjg.trim());
    		if (null != emm) {
    			storehouse.setGround(emm.getEnumid().toString());
    		} else {
    			sbf.append("dmjg参数有误;");
    		}
    	} else {
    		sbf.append("dmjg不能为空;");
    	}

    	//实际仓容
    	String dczlrj = obj.getString("dczlrj");
    	if (StringUtils.isNotBlank(dczlrj)) {
    		storehouse.setActualCapacity(ParameterUtil.getBigDecimal(dczlrj.trim(), 4));
    	}

    	//设计仓容
    	String sjcr = obj.getString("sjcr");
    	if (StringUtils.isNotBlank(sjcr)) {
    		storehouse.setDesignCapacity(ParameterUtil.getBigDecimal(sjcr.trim(), 4));
    	} else {
    		sbf.append("sjcr不能为空;");
    	}

    	//仓外长
    	String cwc = obj.getString("cwc");
    	if (StringUtils.isNotBlank(cwc)) {
    		storehouse.setStoreOutsideLength(ParameterUtil.getBigDecimal(cwc.trim(), 2));
    	}

    	//仓外宽
    	String cwk = obj.getString("cwk");
    	if (StringUtils.isNotBlank(cwk)) {
    		storehouse.setStoreOutsideWidth(ParameterUtil.getBigDecimal(cwk.trim(), 2));
    	}

    	//仓外檐高
    	String cwyg = obj.getString("cwyg");
    	if (StringUtils.isNotBlank(cwyg)) {
    		storehouse.setStoreOutsideHeigth(ParameterUtil.getBigDecimal(cwyg.trim(), 2));
    	}

    	//仓外顶高
    	String cwdg = obj.getString("cwdg");
    	if (StringUtils.isNotBlank(cwdg)) {
    		storehouse.setStoreOutsideTopHeigth(ParameterUtil.getBigDecimal(cwdg.trim(), 2));
    	}

    	//筒仓外径
    	String cwtcwj = obj.getString("cwtcwj");
    	if (StringUtils.isNotBlank(cwtcwj)) {
    		storehouse.setOutsideSiloDiameter(ParameterUtil.getBigDecimal(cwtcwj.trim(), 2));
    	}

    	//仓内长
    	String cnc = obj.getString("cnc");
    	if (StringUtils.isNotBlank(cnc)) {
    		storehouse.setLength(ParameterUtil.getBigDecimal(cnc.trim(), 2));
    	}

    	//仓内宽
    	String cnk = obj.getString("cnk");
    	if (StringUtils.isNotBlank(cnk)) {
    		storehouse.setWidth(ParameterUtil.getBigDecimal(cnk.trim(), 2));
    	}

    	//仓内檐高
    	String cnyg = obj.getString("cnyg");
    	if (StringUtils.isNotBlank(cnyg)) {
    		storehouse.setHeigth(ParameterUtil.getBigDecimal(cnyg.trim(), 2));
    	}

    	//仓内装粮线高
    	String cnzlxg = obj.getString("cnzlxg");
    	if (StringUtils.isNotBlank(cnzlxg)) {
    		storehouse.setGrainLineHeigth(ParameterUtil.getBigDecimal(cnzlxg.trim(), 2));
    	}

    	//筒仓内径
    	String cntcnj = obj.getString("cntcnj");
    	if (StringUtils.isNotBlank(cntcnj)) {
    		storehouse.setSiloDiameter(ParameterUtil.getBigDecimal(cntcnj.trim(), 2));
    	}

    	//仓内体积
    	String cntj = obj.getString("cntj");
    	if (StringUtils.isNotBlank(cntj)) {
    		storehouse.setBinVolume(ParameterUtil.getBigDecimal(cntj.trim(), 2));
    	}

    	//仓门数量
    	String cmsl = obj.getString("cmsl");
    	if (StringUtils.isNotBlank(cmsl)) {
    		storehouse.setHouseDoorNum(Integer.parseInt(cmsl));
    	}

    	//挡粮门型式
    	String dlmxs = obj.getString("dlmxs");
    	if (StringUtils.isNotBlank(dlmxs)) {
    		storehouse.setDlmxs(dlmxs.trim());
    	}

    	//仓房是否完好
    	String cfsfwh = obj.getString("cfsfwh");
    	if (StringUtils.isNotBlank(cfsfwh)) {
    		if ("1".equals(cfsfwh)) {
    			storehouse.setStorehouseState(3011);
    		} else {
    			storehouse.setStorehouseState(3017);
    		}
    	} else {
    		sbf.append("cfsfwh不能为空;");
    	}

    	/***** start 遍历仓门信息 ******/
    	JSONObject cmobj = null;
    	String cmwz = null;
    	String cmgd = null;
    	String cmkd = null;
    	
    	cmobj = cmarray.getJSONObject(0);
//    	for (int i = 0; i < cmarray.size(); i++) {

//    		cmobj = cmarray.getJSONObject(i);

    		//仓门位置
    		cmwz = cmobj.getString("cmmc");
    		if (StringUtils.isNotBlank(cmwz)) {
    			storehouse.setHouseDootPosition(cmwz.trim());
    		}
    		
    		//仓门高度
    		cmgd = cmobj.getString("cmgd");
    		if (StringUtils.isNotBlank(cmgd)) {
    			storehouse.setHouseDoorHeigth(ParameterUtil.getBigDecimal(cmgd.trim(), 2));
    		}
    		
    		//仓门宽度
    		cmkd = cmobj.getString("cmkd");
    		if (StringUtils.isNotBlank(cmkd)) {
    			storehouse.setHouseDoorWidth(ParameterUtil.getBigDecimal(cmkd.trim(), 2));
    		}
//    	}
    	/***** end 遍历仓门信息 ******/

    	//储粮功效
    	String clgx = obj.getString("clgx");
    	if (StringUtils.isNotBlank(clgx)) {
    		storehouse.setClgx(Integer.parseInt(clgx.trim()));
    	} else {
    		sbf.append("clgx不能为空;");
    	}

    	//能否隔热保温
    	String nfgrbw = obj.getString("nfgrbw");
    	if (StringUtils.isNotBlank(nfgrbw)) {
    		storehouse.setNfgrbw(Integer.parseInt(nfgrbw.trim()));
    	} else {
    		sbf.append("nfgrbw不能为空;");
    	}

    	//隔热保温措施
    	String grbwcs = obj.getString("grbwcs");
    	if (StringUtils.isNotBlank(grbwcs)) {
    		storehouse.setGrbwcs(grbwcs.trim());
    	}

    	//隔热性能
    	String grxn = obj.getString("grxn");
    	if (StringUtils.isNotBlank(grxn)) {
    		storehouse.setGrxn(Integer.parseInt(grxn.trim()));
    	}

    	//结构材料
    	String jgcl = obj.getString("jgcl");
    	if (StringUtils.isNotBlank(jgcl)) {
    		storehouse.setJgcl(Integer.parseInt(jgcl.trim()));
    	} else {
    		sbf.append("jgcl不能为空;");
    	}

    	//气密性
    	String qmx = obj.getString("qmx");
    	if (StringUtils.isNotBlank(qmx)) {
    		storehouse.setQmx(Integer.parseInt(qmx.trim()));
    	}

    	//是否已进行信息化改造
    	String sfyjxxxhgz = obj.getString("sfyjxxxhgz");
    	if (StringUtils.isNotBlank(sfyjxxxhgz)) {
    		storehouse.setSfyjxxxhgz(Integer.parseInt(sfyjxxxhgz.trim()));
    	} else {
    		sbf.append("sfyjxxxhgz不能为空;");
    	}

    	//粮情技术
    	String lqjs = obj.getString("lqjs");
    	if (StringUtils.isNotBlank(lqjs)) {
    		storehouse.setLqjs(Integer.parseInt(lqjs.trim()));
    	} else {
    		sbf.append("lqjs不能为空;");
    	}

    	//能否散装储存
    	String sfszcc = obj.getString("sfszcc");
    	if (StringUtils.isNotBlank(sfszcc)) {
    		storehouse.setNfszcc(Integer.parseInt(sfszcc.trim()));
    	} else {
    		sbf.append("sfszcc不能为空;");
    	}

    	//有无防鼠防雀防虫装置及设施
    	String ywfsfqfczz = obj.getString("ywfsfqfczz");
    	if (StringUtils.isNotBlank(ywfsfqfczz)) {
    		storehouse.setYwfsfqfczz(Integer.parseInt(ywfsfqfczz.trim()));
    	} else {
    		sbf.append("ywfsfqfczz不能为空;");
    	}

    	//有无防火防爆防盗设施Y
    	String ywfhfbfdss = obj.getString("ywfhfbfdss");
    	if (StringUtils.isNotBlank(ywfhfbfdss)) {
    		storehouse.setYwfhfbfdss(Integer.parseInt(ywfhfbfdss.trim()));
    	} else {
    		sbf.append("ywfhfbfdss不能为空;");
    	}

    	//有无机械通风设施Y
    	String ywjxtfss = obj.getString("ywjxtfss");
    	if (StringUtils.isNotBlank(ywjxtfss)) {
    		storehouse.setYwjxtfss(Integer.parseInt(ywjxtfss.trim()));
    	} else {
    		sbf.append("ywjxtfss不能为空;");
    	}

    	//通风系统型式
    	String tfxtxs = obj.getString("tfxtxs");
    	if (StringUtils.isNotBlank(tfxtxs)) {
    		storehouse.setTfxtxs(Integer.parseInt(tfxtxs.trim()));
    	}

    	//通风技术Y
    	String tfjs = obj.getString("tfjs");
    	if (StringUtils.isNotBlank(tfjs)) {
    		storehouse.setTfjs(Integer.parseInt(tfjs.trim()));
    	} else {
    		sbf.append("tfjs不能为空;");
    	}

    	//能否环流熏蒸杀虫Y
    	String nfxlsc = obj.getString("nfxlsc");
    	if (StringUtils.isNotBlank(nfxlsc)) {
    		storehouse.setNfhlxzsc(Integer.parseInt(nfxlsc.trim()));
    	} else {
    		sbf.append("nfxlsc不能为空;");
    	}

    	//杀虫技术
    	String scjs = obj.getString("scjs");
    	if (StringUtils.isNotBlank(scjs)) {
    		storehouse.setScjs(Integer.parseInt(scjs.trim()));
    	}

    	//能否富氮低氧气调储粮Y
    	String nffddyqtcl = obj.getString("nffddyqtcl");
    	if (StringUtils.isNotBlank(nffddyqtcl)) {
    		storehouse.setNffddyqtcl(Integer.parseInt(nffddyqtcl.trim()));
    	} else {
    		sbf.append("nffddyqtcl不能为空;");
    	}

    	//控温技术
    	String kwjs = obj.getString("kwjs");
    	if (StringUtils.isNotBlank(kwjs)) {
    		storehouse.setKwjs(Integer.parseInt(kwjs.trim()));
    	}

    	//害虫检测方式Y
    	String hcjcfs = obj.getString("hcjcfs");
    	if (StringUtils.isNotBlank(hcjcfs)) {
    		storehouse.setHcjcfs(hcjcfs.trim());
    	} else {
    		sbf.append("hcjcfs不能为空;");
    	}

    	//仓房状态Y
    	String cfzt = obj.getString("cfzt");
    	if (StringUtils.isNotBlank(cfzt)) {
    		BasicEnum emm = basicEnumService.getBasicEnum(1001, cfzt.trim());
    		if (null != emm) {
    			storehouse.setStorehouseState(emm.getEnumid());
    		} else {
    			sbf.append("cfzt参数有误;");
    		}
    	} else {
    		sbf.append("cfzt不能为空;");
    	}
    	
    	//有无粮情检测设施
    	String ywlqckqk = obj.getString("ywlqckqk");
    	if (StringUtils.isNotBlank(ywlqckqk)) {
    		storehouse.setYwlqjcss(Integer.parseInt(ywlqckqk.trim()));
    	}
    	
    	//廒间标准编码
    	String ajdh = obj.getString("ajdh");
    	if (StringUtils.isNotBlank(ajdh) && ajdh.length() == 28) {
    		storehouse.setAjbm(ajdh.trim());
    	} else {
    		sbf.append("ajdh不能为空并且必须是28位;");
    	}
    	
//    	String delflag = obj.getString("status");
//    	if (StringUtils.isNotBlank(delflag)) {
//    		storehouse.setDelFlag(Integer.parseInt(delflag.trim()));
//    	} else {
//    		sbf.append("status仓房的弃用状态不能为空;");
//    	}

		String msg = sbf.toString();

		map.put("msg", msg);

		map.put("storehouse", storehouse);

		map.put("ware_list", ware_list);

		map.put("isadd_map", isadd_map);

		return map;
	}

	@Override
	public Map<String, Object> getCfGjjDate(Integer i) {
		// TODO Auto-generated method stub
		return basic.getCfGjjDate(i);
	}

	@Override
	public List<BasicStorehouse> getEmptyStorehouse(Integer orgId) {
		// TODO Auto-generated method stub
		return basic.getEmptyStorehouse(orgId);
	}

	@Override
	public Map<String, Object> getgjj() {
		// TODO Auto-generated method stub
		return gjjMapper.getKqGjjDate("15");
	}

}
